@@ -1,8 +1,8 @@
 from __future__ import annotations
 
+import inspect
 import typing as t
 
-import sqlglot
 from sqlglot import Schema, exp
 from sqlglot.dialects.dialect import DialectType
 from sqlglot.optimizer.annotate_types import annotate_types
@@ -10,26 +10,20 @@ from sqlglot.optimizer.canonicalize import canonicalize
 from sqlglot.optimizer.eliminate_ctes import eliminate_ctes
 from sqlglot.optimizer.eliminate_joins import eliminate_joins
 from sqlglot.optimizer.eliminate_subqueries import eliminate_subqueries
-from sqlglot.optimizer.isolate_table_selects import isolate_table_selects
-from sqlglot.optimizer.lower_identities import lower_identities
 from sqlglot.optimizer.merge_subqueries import merge_subqueries
 from sqlglot.optimizer.normalize import normalize
 from sqlglot.optimizer.optimize_joins import optimize_joins
 from sqlglot.optimizer.pushdown_predicates import pushdown_predicates
 from sqlglot.optimizer.pushdown_projections import pushdown_projections
-from sqlglot.optimizer.qualify_columns import qualify_columns, validate_qualify_columns
-from sqlglot.optimizer.qualify_tables import qualify_tables
+from sqlglot.optimizer.qualify import qualify
+from sqlglot.optimizer.qualify_columns import quote_identifiers
 from sqlglot.optimizer.simplify import simplify
 from sqlglot.optimizer.unnest_subqueries import unnest_subqueries
 from sqlglot.schema import ensure_schema
 
 RULES = (
-    lower_identities,
-    qualify_tables,
-    isolate_table_selects,
-    qualify_columns,
+    qualify,
     pushdown_projections,
-    validate_qualify_columns,
     normalize,
     unnest_subqueries,
     pushdown_predicates,
@@ -38,6 +32,7 @@ RULES = (
     merge_subqueries,
     eliminate_joins,
     eliminate_ctes,
+    quote_identifiers,
     annotate_types,
     canonicalize,
     simplify,
@@ -47,12 +42,13 @@ RULES = (
 def optimize(
     expression: str | exp.Expression,
     schema: t.Optional[dict | Schema] = None,
-    db: t.Optional[str] = None,
-    catalog: t.Optional[str] = None,
+    db: t.Optional[str | exp.Identifier] = None,
+    catalog: t.Optional[str | exp.Identifier] = None,
     dialect: DialectType = None,
     rules: t.Sequence[t.Callable] = RULES,
+    sql: t.Optional[str] = None,
     **kwargs,
-):
+) -> exp.Expression:
     """
     Rewrite a sqlglot AST into an optimized form.
 
@@ -70,22 +66,33 @@ def optimize(
         dialect: The dialect to parse the sql string.
         rules: sequence of optimizer rules to use.
             Many of the rules require tables and columns to be qualified.
-            Do not remove qualify_tables or qualify_columns from the sequence of rules unless you know
-            what you're doing!
+            Do not remove `qualify` from the sequence of rules unless you know what you're doing!
+        sql: Original SQL string for error highlighting. If not provided, errors will not include
+            highlighting. Requires that the expression has position metadata from parsing.
         **kwargs: If a rule has a keyword argument with a same name in **kwargs, it will be passed in.
-    Returns:
-        sqlglot.Expression: optimized expression
-    """
-    schema = ensure_schema(schema or sqlglot.schema, dialect=dialect)
-    possible_kwargs = {"db": db, "catalog": catalog, "schema": schema, **kwargs}
-    expression = exp.maybe_parse(expression, dialect=dialect, copy=True)
 
+    Returns:
+        The optimized expression.
+    """
+    schema = ensure_schema(schema, dialect=dialect)
+    possible_kwargs = {
+        "db": db,
+        "catalog": catalog,
+        "schema": schema,
+        "dialect": dialect,
+        "sql": sql,
+        "isolate_tables": True,  # needed for other optimizations to perform well
+        "quote_identifiers": False,
+        **kwargs,
+    }
+
+    optimized = exp.maybe_parse(expression, dialect=dialect, copy=True)
     for rule in rules:
         # Find any additional rule parameters, beyond `expression`
-        rule_params = rule.__code__.co_varnames
+        rule_params = inspect.getfullargspec(rule).args
         rule_kwargs = {
             param: possible_kwargs[param] for param in rule_params if param in possible_kwargs
         }
-        expression = rule(expression, **rule_kwargs)
+        optimized = rule(optimized, **rule_kwargs)
 
-    return expression
+    return optimized
